@@ -3,7 +3,7 @@
 ** Purpose:     Amalgamation of the SQLite3 Multiple Ciphers encryption extension for SQLite
 ** Author:      Ulrich Telle
 ** Created:     2020-02-28
-** Copyright:   (c) 2006-2024 Ulrich Telle
+** Copyright:   (c) 2006-2025 Ulrich Telle
 ** License:     MIT
 */
 
@@ -37,19 +37,6 @@
 #endif
 #endif
 
-/*
-** Define function for extra initialization and extra shutdown
-**
-** The extra initialization function registers an extension function
-** which will be automatically executed for each new database connection.
-**
-** The extra shutdown function will be executed on the invocation of sqlite3_shutdown.
-** All created multiple ciphers VFSs will be unregistered and destroyed.
-*/
-
-#define SQLITE_EXTRA_INIT sqlite3mc_initialize
-#define SQLITE_EXTRA_SHUTDOWN sqlite3mc_shutdown
-
 /*
 ** Declare all internal functions as 'static' unless told otherwise
 */
@@ -381,7 +368,8 @@ mcRegisterCodecExtensions(sqlite3* db, char** pzErrMsg, const sqlite3_api_routin
   int rc = SQLITE_OK;
   CodecParameter* codecParameterTable = NULL;
 
-  if (sqlite3FindFunction(db, "sqlite3mc_config_table", 1, SQLITE_UTF8, 0) != NULL)
+  void* codecParamTable = sqlite3_get_clientdata(db, globalConfigTableName);
+  if (codecParamTable)
   {
     /* Return if codec extension functions are already defined */
     return rc;
@@ -392,8 +380,7 @@ mcRegisterCodecExtensions(sqlite3* db, char** pzErrMsg, const sqlite3_api_routin
   rc = (codecParameterTable != NULL) ? SQLITE_OK : SQLITE_NOMEM;
   if (rc == SQLITE_OK)
   {
-    rc = sqlite3_create_function_v2(db, "sqlite3mc_config_table", 0, SQLITE_UTF8 | SQLITE_DETERMINISTIC,
-                                    codecParameterTable, sqlite3mcConfigTable, 0, 0, sqlite3mcFreeCodecParameterTable);
+    sqlite3_set_clientdata(db, globalConfigTableName, codecParameterTable, sqlite3mcFreeCodecParameterTable);
   }
 
   rc = (codecParameterTable != NULL) ? SQLITE_OK : SQLITE_NOMEM;
@@ -538,8 +525,6 @@ sqlite3mcRegisterCipher(const CipherDescriptor* desc, const CipherParams* params
   if (!cipherParams)
     return SQLITE_NOMEM;
 
-  sqlite3_mutex_enter(sqlite3_mutex_alloc(SQLITE_MUTEX_STATIC_MAIN));
-
   /* Check for */
   if (globalCipherCount < CODEC_COUNT_MAX)
   {
@@ -589,8 +574,6 @@ sqlite3mcRegisterCipher(const CipherDescriptor* desc, const CipherParams* params
     rc = SQLITE_NOMEM;
   }
 
-  sqlite3_mutex_leave(sqlite3_mutex_alloc(SQLITE_MUTEX_STATIC_MAIN));
-
   return rc;
 }
 
@@ -602,7 +585,10 @@ sqlite3mc_register_cipher(const CipherDescriptor* desc, const CipherParams* para
   rc = sqlite3_initialize();
   if (rc) return rc;
 #endif
-  return sqlite3mcRegisterCipher(desc, params, makeDefault);
+  sqlite3_mutex_enter(sqlite3_mutex_alloc(SQLITE_MUTEX_STATIC_MAIN));
+  rc = sqlite3mcRegisterCipher(desc, params, makeDefault);
+  sqlite3_mutex_leave(sqlite3_mutex_alloc(SQLITE_MUTEX_STATIC_MAIN));
+  return rc;
 }
 
 SQLITE_PRIVATE int
@@ -610,6 +596,15 @@ sqlite3mcInitCipherTables()
 {
   size_t n;
 
+  /* Initialize global configuration table name */
+  sqlite3_randomness(CIPHER_NAME_MAXLEN, globalConfigTableName);
+  for (n = 0; n < CIPHER_NAME_MAXLEN-1; ++n)
+  {
+    if (globalConfigTableName[n] == 0)
+      globalConfigTableName[n] = '@';
+  }
+  globalConfigTableName[CIPHER_NAME_MAXLEN-1] = 0;
+
   /* Initialize cipher name table */
   strcpy(globalCipherNameTable[0].m_name, "global");
   for (n = 1; n < CODEC_COUNT_MAX + 2; ++n)
@@ -709,84 +704,92 @@ sqlite3mc_initialize(const char* arg)
   {
     rc = sqlite3mc_vfs_create(NULL, 1);
   }
+  return rc;
+}
+
+SQLITE_PRIVATE int
+sqlite3mc_builtin_extensions(sqlite3* db)
+{
+  char* errmsg = NULL;
+  int rc = SQLITE_OK;
 
   /*
   ** Register Multi Cipher extension
   */
   if (rc == SQLITE_OK)
   {
-    rc = sqlite3_auto_extension((void(*)(void)) mcRegisterCodecExtensions);
+    rc = mcRegisterCodecExtensions(db, &errmsg, NULL);
   }
 #ifdef SQLITE_ENABLE_EXTFUNC
   if (rc == SQLITE_OK)
   {
-    rc = sqlite3_auto_extension((void(*)(void)) sqlite3_extfunc_init);
+    rc = sqlite3_extfunc_init(db, &errmsg, NULL);
   }
 #endif
 #ifdef SQLITE_ENABLE_CSV
   if (rc == SQLITE_OK)
   {
-    rc = sqlite3_auto_extension((void(*)(void)) sqlite3_csv_init);
+    rc = sqlite3_csv_init(db, &errmsg, NULL);
   }
 #endif
 #ifdef SQLITE_ENABLE_VSV
   if (rc == SQLITE_OK)
   {
-    rc = sqlite3_auto_extension((void(*)(void)) sqlite3_vsv_init);
+    rc = sqlite3_vsv_init(db, &errmsg, NULL);
   }
 #endif
 #ifdef SQLITE_ENABLE_SHA3
   if (rc == SQLITE_OK)
   {
-    rc = sqlite3_auto_extension((void(*)(void)) sqlite3_shathree_init);
+    rc = sqlite3_shathree_init(db, &errmsg, NULL);
   }
 #endif
 #ifdef SQLITE_ENABLE_CARRAY
   if (rc == SQLITE_OK)
   {
-    rc = sqlite3_auto_extension((void(*)(void)) sqlite3_carray_init);
+    rc = sqlite3_carray_init(db, &errmsg, NULL);
   }
 #endif
 #ifdef SQLITE_ENABLE_FILEIO
   if (rc == SQLITE_OK)
   {
-    rc = sqlite3_auto_extension((void(*)(void)) sqlite3_fileio_init);
+    rc = sqlite3_fileio_init(db, &errmsg, NULL);
   }
 #endif
 #ifdef SQLITE_ENABLE_SERIES
   if (rc == SQLITE_OK)
   {
-    rc = sqlite3_auto_extension((void(*)(void)) sqlite3_series_init);
+    rc = sqlite3_series_init(db, &errmsg, NULL);
   }
 #endif
 #ifdef SQLITE_ENABLE_UUID
   if (rc == SQLITE_OK)
   {
-    rc = sqlite3_auto_extension((void(*)(void)) sqlite3_uuid_init);
+    rc = sqlite3_uuid_init(db, &errmsg, NULL);
   }
 #endif
 #ifdef SQLITE_ENABLE_REGEXP
   if (rc == SQLITE_OK)
   {
-    rc = sqlite3_auto_extension((void(*)(void)) sqlite3_regexp_init);
+    rc = sqlite3_regexp_init(db, &errmsg, NULL);
   }
 #endif
 #ifdef SQLITE_ENABLE_COMPRESS
   if (rc == SQLITE_OK)
   {
-    rc = sqlite3_auto_extension((void(*)(void)) sqlite3_compress_init);
+    rc = sqlite3_compress_init(db, &errmsg, NULL);
   }
 #endif
 #ifdef SQLITE_ENABLE_SQLAR
   if (rc == SQLITE_OK)
   {
-    rc = sqlite3_auto_extension((void(*)(void)) sqlite3_sqlar_init);
+    rc = sqlite3_sqlar_init(db, &errmsg, NULL);
   }
 #endif
 #ifdef SQLITE_ENABLE_ZIPFILE
   if (rc == SQLITE_OK)
   {
-    rc = sqlite3_auto_extension((void(*)(void)) sqlite3_zipfile_init);
+    rc = sqlite3_zipfile_init(db, &errmsg, NULL);
   }
 #endif
   return rc;
